import 'package:flutter/material.dart';

import 'package:random/models/game_data.dart';
import 'package:random/ui/painters/cell_painter.dart';

class GameBoardWidget extends StatelessWidget {
  const GameBoardWidget({super.key, required this.gameData});

  final GameData gameData;

  @override
  Widget build(BuildContext context) {
    const staticBoardWidth = 300;
    const staticBoardHeight = 300;

    final rowsCount = this.gameData.board.length;
    final columnsCount = this.gameData.board[0].length;
    print('counts: rows=' + rowsCount.toString() + ' / columns=' + columnsCount.toString());

    final cellWidth = staticBoardWidth / columnsCount;
    final cellHeight = staticBoardHeight / rowsCount;
    print('cell: width=' + cellWidth.toString() + ' / height=' + cellHeight.toString());

    final List<Widget> cells = [];

    for (var y = 0; y < rowsCount; y++) {
      for (var x = 0; x < columnsCount; x++) {
        final GameDataItem item = this.gameData.board[y][x];

        final Widget cellContent = CustomPaint(
          size: Size(cellWidth, cellHeight),
          willChange: false,
          painter: CellPainter(value: item.value),
        );

        final Widget widget = Positioned(
          left: (x * cellWidth).toDouble(),
          top: (y * cellHeight).toDouble(),
          child: Container(
            width: cellWidth,
            height: cellHeight,
            color: Colors.deepPurpleAccent,
            child: cellContent,
          ),
        );

        cells.add(widget);
      }
    }

    return Container(
      width: staticBoardWidth.toDouble(),
      height: staticBoardHeight.toDouble(),
      color: Colors.grey,
      child: Stack(
        children: cells,
      ),
    );
  }
}
